@@ -38,6 +38,7 @@ from tempest.lib import exceptions as lib_exc
 
 CONF = config.CONF
 LOG = log.getLogger(__name__)
+FRR_BASE_IMAGE = 'quay.io/nf-core/ubuntu:22.04'
 
 
 class FRROCIImage(ctn_base.DockerImage):
@@ -47,7 +48,7 @@ class FRROCIImage(ctn_base.DockerImage):
         baseimage: typing.Optional[str] = None,
         use_existing: bool = False,
     ):
-        super().__init__(baseimage=baseimage or 'ubuntu:22.04')
+        super().__init__(baseimage=baseimage or FRR_BASE_IMAGE)
         self.daemons = daemons
         self.tagname = 'frr-' + '-'.join(daemons)
         if use_existing and self.exist(self.tagname):
@@ -629,7 +630,8 @@ class NetworkMultipleGWTest(base.BaseAdminTempestTestCase):
     def test_update_router_single_gw_bfd(self):
         ext_network_id = self.ext_networks[0][0]['id']
         bfd_container = self.containers[0]
-        router = self.create_router(
+        router = self._create_router_with_client(
+            self.admin_client,
             router_name=data_utils.rand_name('router'),
             admin_state_up=True,
             enable_snat=False,
